/**
 * Copyright (c) 2013-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring.exception;

import org.ow2.petals.cli.api.command.Command;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.extension.command.monitoring.so.api.SubscriptionObject;

/**
 * A subscription already exists for a subscription object.
 * 
 * @author Christophe DENEUX - Linagora
 */
public class SubscriptionAlreadyExistsException extends CommandException {
    
    private static final long serialVersionUID = 2621486193502473111L;

    private static final String MESSAGE_TEMPLATE = "A subscription already exists for the subscription object '%s'";

    /**
     * The name of the subscription object already subscribed.
     */
    private final String subscriptionObjectName;
    
    public SubscriptionAlreadyExistsException(final Command command, final SubscriptionObject subscriptionObject) {
        super(command, String.format(MESSAGE_TEMPLATE, subscriptionObject.getName()));
        this.subscriptionObjectName = subscriptionObject.getName();
    }

    /**
     * @return The name of the subscription object already subscribed.
     */
    public String getSubscriptionObjectName() {
        return this.subscriptionObjectName;
    }

}
