/**
 * Copyright (c) 2013-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.command.monitoring;

import java.util.Arrays;
import java.util.List;

import org.apache.commons.cli.Options;
import org.ow2.petals.cli.api.shell.Shell;
import org.ow2.petals.cli.extension.command.monitoring.so.api.EmittableDefect;
import org.ow2.petals.cli.extension.command.monitoring.so.api.SubscriptionObject;
import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.SubscriptionObjectBadArgumentNumberException;
import org.ow2.petals.cli.extension.command.monitoring.so.api.exception.SubscriptionObjectException;

/**
 * <p>
 * Dummy subscription object for unit test purpose with following
 * characteristics:
 * <ul>
 * <li>no arguments,</li>
 * <li>without description,</li>
 * <li>a unique dummy emittable defect without description.</li>
 * </ul>
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class DummySO implements SubscriptionObject {

    public final static String NAME = "dummy-so";

    public final static String DEFECT_NAME = "dummy-defect";

    private final EmittableDefect[] DEFECTS = new EmittableDefect[] { new EmittableDefect() {

        @Override
        public String getName() {
            return DEFECT_NAME;
        }

        @Override
        public String getDescription() {
            return null;
        }
    } };

    @Override
    public List<EmittableDefect> getEmittableDefects() {
        return Arrays.asList(DEFECTS);
    }

    @Override
    public String getName() {
        return NAME;
    }

    @Override
    public String getDescription() {
        return null;
    }

    @Override
    public void subscribe(final String[] args) throws SubscriptionObjectBadArgumentNumberException,
            SubscriptionObjectException {
        // NOP
    }

    @Override
    public void unsubscribe(String[] args) throws SubscriptionObjectBadArgumentNumberException,
            SubscriptionObjectException {
        // NOP
    }

    @Override
    public void resetOptions() {
        // NOP
    }

    @Override
    public void setShell(final Shell shell) {
        // NOP
    }

    @Override
    public Shell getShell() {
        return null;
    }

    @Override
    public Options getOptions() {
        return null;
    }

}
